@@ -57,9 +57,7 @@ TF002.anovaMM.balanced1 <- function()
 	
 }
 
-# checks whether both function yield identical results when fitting a random model, 
-# once setting negative variance estimates equal to zero, and once allowing negative 
-# variance estimates
+# checks whether both functions yield identical results when fitting a random model
 
 TF003.anovaMM.NegVC.balanced <- function()
 {
@@ -69,15 +67,10 @@ TF003.anovaMM.NegVC.balanced <- function()
 	set.seed(123)
 	test.dat$y <- test.dat$y + rnorm(40,,2.5)						# add something which yields negative estimates
 	
-	resRM1 <- remlVCA(y~day/run, test.dat)							# constrain VC to 0
+	resRM1 <- remlVCA(y~day/run, test.dat)							# constrain negative VC to zero by design
 	resMM1 <- remlMM(y~(day)/(run), test.dat)
 	
 	checkEquals(resRM1$aov.tab, resMM1$aov.tab)
-	
-	resRM2 <- remlVCA(y~day/run, test.dat)			# allowing negative VCs
-	resMM2 <- remlMM(y~(day)/(run), test.dat)
-	
-	checkEquals(resRM1$aov.tab, resMM1$aov.tab)
 }
 
 # test againts SAS PROC MIXED:
@@ -210,3 +203,25 @@ TF011.remlMM.zeroVariance <- function()
 }
 
 
+TF012.remlMM.byProcessing <- function() 
+{
+	# reproducible example taken from ticket 12818
+	set.seed(42)
+	dat <- expand.grid(group=c("group1", "group2"), day=rep(c("day1","day2"), times=3))
+	dat$value <- rnorm(nrow(dat))
+	
+	dat <- subset(dat, !(group=="group2" & day=="day1")) #dataset with valid vca input for group 1 but invalid input for group 2
+	
+#	VCA::anovaVCA(value~day, Data = subset(dat, group=="group1"), by="group") #valud result (as epcected)
+#	VCA::anovaVCA(value~day, Data = subset(dat, group=="group2"), by="group") #invalid result (as expected)
+	
+	# should generate a warning if quiet=FALSE
+	checkTrue(	tryCatch(
+					remlMM(value~(day), Data = dat, by = "group", quiet=FALSE),
+					warning=function(w) TRUE) )
+	# should not generate a warning if quiet=TRUE
+	res <- remlMM(value~(day), Data = dat, by = "group", quiet=TRUE)
+	checkTrue(	class(res) == "list" && 
+					length(res) == 2 &&  
+					all.equal(c("VCA", "try-error"), as.character(sapply(res, class))))
+}
